@@ -409,14 +409,14 @@ class NumerousClient:
 
         self._base_client.PushScenarioError(spm_pb2.ScenarioError(project=self._project, scenario=scenario, error=error, spm_job_id=self._job_id))
 
-    def push_scenario_log(self, message, initialize=False, scenario=None):
-        if scenario is None:
-            scenario = self._scenario
+    #def push_scenario_log(self, message, initialize=False, scenario=None):
+    #    if scenario is None:
+    #        scenario = self._scenario
 
-        self._base_client.PushScenarioLogEntry(spm_pb2.ScenarioLogEntry(
-            project=self._project, scenario=scenario, message=message,
-            spm_job_id=self._job_id, initialize=initialize
-        ))
+    #    self._base_client.PushScenarioLogEntr(spm_pb2.ScenarioLogEntry(
+    #        project=self._project, scenario=scenario, message=message,
+    #        spm_job_id=self._job_id, initialize=initialize
+    #    ))
 
     def push_scenario_logs(self, logs):
 
@@ -442,7 +442,7 @@ class NumerousClient:
     #    project = "Xcqmc04Ckc9y7IbG6BWa"
     #    scenario = "pYyQFfXoCMZ2Tp6whbak"
 
-        files = self._base_client.GetSignedURLs(spm_pb2.FileSignedUrls(files=[spm_pb2.FileSignedUrl(path=scenario+'/'+f) for f in files]))
+        files = self._base_client.GetSignedURLs(spm_pb2.FileSignedUrls(files=[spm_pb2.FileSignedUrl(path=scenario+'/'+f) for f in files], scenario=scenario))
 
         files_out = {}
         for f in files.files:
@@ -453,14 +453,14 @@ class NumerousClient:
             files_out[f.name] = local_file_path
         return files_out
 
-    def upload_file(self, local_file, file_id, file=None, scenario=None):
+    def upload_file(self, local_file, file_id, file=None, scenario=None, content_type="text/html"):
         if scenario is None:
             scenario = self._scenario
 
         if file is None:
             file = local_file.split('/')[-1]
         #print('File: ', file)
-        upload_url = self._base_client.GenerateScenarioUploadSignedURL(spm_pb2.ScenarioFilePath(project=self._project, scenario=scenario, path=file, file_id=file_id))
+        upload_url = self._base_client.GenerateScenarioUploadSignedURL(spm_pb2.ScenarioFilePath(project=self._project, scenario=scenario, path=file, file_id=file_id, content_type=content_type))
 
         def upload():
             filename = local_file
@@ -470,7 +470,7 @@ class NumerousClient:
             headers = {"Content-Type": "multipart/related"}
             params = {
                 "name": file,
-                "mimeType": "text/html"
+                "mimeType": content_type
             }
             r = requests.post(
                 upload_url.url,
@@ -488,6 +488,43 @@ class NumerousClient:
 
         return self._base_client.GetScenarioMetaData(spm_pb2.Scenario(scenario=scenario))
 
+    def set_timeseries_meta_data(self, tags, aliases, offset=0, timezone='UTC', epoch_type='s', scenario= None):
+
+        def g(tag, key, def_):
+            if key in tag:
+                return tag[key]
+            elif def_ is not None:
+                return def_
+            else:
+                raise KeyError(f'No default for key: {key}')
+
+        def wrap_tag(tag):
+
+            kwargs = {k: g(tag,k,d) for k, d in {
+                'name': None,
+                'displayName': '',
+                'unit': '',
+                'description': '',
+                'type': 'double',
+                'scaling': 1,
+                'offset': 0
+            }.items()}
+            print(kwargs)
+            return spm_pb2.Tag(
+                **kwargs
+            )
+
+        if scenario is None:
+            scenario = self._scenario
+
+        return self._base_client.SetScenarioMetaData(
+            spm_pb2.ScenarioMetaData(scenario=scenario,
+            tags=[wrap_tag(tag) for tag in tags],
+            aliases=[spm_pb2.Alias(tag=k, aliases=v) for k,v in aliases.items()],
+                                     offset=offset, timezone=timezone, epoch_type=epoch_type
+                            )
+        )
+
     def get_timeseries_custom_meta_data(self, scenario=None, key=None):
         if scenario is None:
             scenario = self._scenario
@@ -1031,7 +1068,7 @@ class Test(NumerousClient):
 class NumerousAdminClient(NumerousClient):
     def __init__(self, server=None, port=None, secure=None, refresh_token=None, instance_id=None):
         super(NumerousAdminClient, self).__init__(
-            server=server, port=port, secure=secure, refresh_token=refresh_token, instance_id=instance_id
+            server=server, port=port, secure=secure, refresh_token=refresh_token, instance_id=instance_id, project="", scenario="", job_id=""
         )
         self._job_manager = spm_pb2_grpc.JobManagerStub(self.channel)
         self._terminated = False
